#
# spec file for package python-dmidecode
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-dmidecode
Version:        3.12.2
Release:        150400.12.6
Summary:        Python module to access DMI data
Group:          System/Management
License:        GPL-2.0-only
URL:            https://github.com/nima/python-dmidecode
Source0:        https://github.com/nima/python-dmidecode/archive/refs/tags/v%{version}.tar.gz#/python-dmidecode-%{version}.tar.gz
Patch0:         huge-memory.patch
Patch1:         gcc7-inline.patch
Patch2:         detect-lib-with-py3.patch
# PATCH-FIX-UPSTREAM 31-version_info-v-version.patch gh#nima/python-dmidecode#31 mcepl@suse.com
# use sys.version_info instead of sys.version
Patch3:         31-version_info-v-version.patch
Provides:       %{oldpython}-dmidecode = %{version}-%{release}
Obsoletes:      %{oldpython}-dmidecode < %{version}-%{release}
BuildRequires:  %{python_module devel}
%if 0%{?sle_version} >= 150400
BuildRequires:  %{python_module libxml2}
%else
BuildRequires:  python2-libxml2-python
BuildRequires:  python3-libxml2-python
%endif
BuildRequires:  libxml2-devel
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post):   update-alternatives
Requires(postun):  update-alternatives
%python_subpackages

%description
python-dmidecode is a python extension module that uses the code-base
of the 'dmidecode' utility, and presents the data as python data
structures or as XML data using libxml2.

%prep
%autosetup -p1

sed -i 's/python2/python3/g' Makefile unit-tests/Makefile

%build
%{python_expand export LDFLAGS="-Wl,-rpath=%{$python_sitearch}"
%make_build build
}

%install
%{python_expand rm -f %{buildroot}%{_datadir}/python-dmidecode/pymap.xml
$python src/setup.py install --root %{buildroot} --prefix=%{_prefix}
ls -l %{buildroot}%{_datadir}/python-dmidecode/
mv %{buildroot}%{_datadir}/python-dmidecode/pymap{,-%{$python_bin_suffix}}.xml
touch %{buildroot}%{_datadir}/python-dmidecode/pymap.xml
%fdupes %{buildroot}%{$python_sitearch}
}

%check
pushd unit-tests
%make_build
popd

%clean

%post
PRIO=$(echo %{python_version}|tr -d '.')
/usr/sbin/update-alternatives --install %{_datadir}/python-dmidecode/pymap.xml pymap.xml \
    %{_datadir}/python-dmidecode/pymap-%{python_bin_suffix}.xml ${PRIO}

%postun
if [ ! -f %{_datadir}/python-dmidecode/pymap-%{python_bin_suffix}.xml ] ; then
   MAJVER=$(ver=%{python_version}; echo ${ver:0:1})
   /usr/sbin/update-alternatives --remove pymap.xml \
        %{_datadir}/python-dmidecode/pymap-%{python_bin_suffix}.xml
fi



%files %{python_files}
%license doc/LICENSE
%doc README doc/README.upstream doc/AUTHORS doc/AUTHORS.upstream
%dir %{_datadir}/python-dmidecode/
%ghost %{_sysconfdir}/alternatives/pymap.xml
%ghost %{_datadir}/python-dmidecode/pymap.xml
%{_datadir}/python-dmidecode/pymap-%{python_bin_suffix}.xml
%{python_sitearch}/dmidecode*
%{python_sitearch}/*.egg-info
%pycache_only %{python_sitearch}/__pycache__/*

%changelog
* Mon Feb 28 2022 mcepl@suse.com
- Add proper Provides/Obsoletes
* Thu Feb 24 2022 mcepl@suse.com
- Fix dealing with update-alternatives.
* Mon Feb 21 2022 mcepl@suse.com
- Introduce update-alternatives for
  /usr/share/python-dmidecode/pymap.xml.
* Thu Dec  2 2021 mcepl@suse.com
- Brutal simplification of the SPEC file to the standard single-spec
  Python one.
- Removal of support for Python 2 (bsc#1193262)
- Rename huge-memory.diff to huge-memory.patch (i.e., remove
  huge-memory.diff and add huge-memory.patch).
- Fix URL of Source0 (their own website is down, use GitHub
  release).
- Add 31-version_info-v-version.patch to make tests 3.10
  compatible.
* Thu Oct 19 2017 mc@suse.com
- build python2-dmidecode and use python-dmidecode for shared files
* Tue Oct 17 2017 mc@suse.com
- set rpath to libxml2mod library
* Sun Sep 24 2017 mc@suse.com
- version 3.12.2
- Add Python 3 subpackage
- Removed deprecated statements
* Wed May  3 2017 mantel@suse.de
- use correct data type DWORD for extended memory size (bsc#1036061)
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Fri Jan 17 2014 mc@suse.de
- version 3.12.1
  obsoleted patches (available in new upstream version):
  * python-dmidecode_copyright-update.patch
  * bug-713982_python-dmidecode-nullversion.patch
  * python-dmidecode-dmixml-error-63fa74b229dd2.patch
  * bug-823328-fix-set_vendor-segfault.dif
- Add SIGILL catcher in mem_chunk()
- Implemented dmixml_AddDMIstring()
- Harden dmi_string() calls with better NULL checks
- Do not add explictly 'dmispec' attributes inside switch()
  in dmi_decode()
- rebase against upstream dmidecode v2.12 and an update
  against the SMBIOS reference specification v2.8.0.
* Tue Jun 11 2013 mc@suse.de
- fix segfault in dmi_set_vendor (bnc#823328)
* Wed Sep 28 2011 mc@suse.de
- fix dmi_decode assertion during client registration
  (bnc#720885)
* Mon Sep 12 2011 mc@suse.de
- fix Segfault when decoding DMI data in dmi_processor_id()
  (bnc#713982)
* Thu Dec  9 2010 mc@suse.de
- initial release
